pro thm_part_spec_calc ,types=types, probes=probes, moments=moms, comps=comps, get_moments=get_moments, $
    units=units

;check inputs (Matt D. 7/20)
;-----------------------------------------------------------------------

vprobes=['a','b','c','d','e']
vtypes=['psif','psef']

if not keyword_set(probes) then probes=vprobes
probes=thm_check_valid_name(strtrim(strlowcase(probes),2),vprobes,/include_all)

if probes(0) eq '' then begin
  print,"Invalid probes selected.  Valid probes: 'a','b','c','d' or 'e'  (ie, probe='a')"
  return
end

if not keyword_set(types) then types=vtypes
types=thm_check_valid_name(strtrim(strlowcase(types),2),vtypes,/include_all)

if types(0) eq '' then begin
  print,"Invalid probes selected.  Valid probes: 'psif','psef','peif' or 'peef'  (ie, types='psif')"
  return
end



;Davin's input defaults (mimicked above but with some input error checks)
;if not keyword_set(types)   then types = ['peif','peef','psif','psef']
;if not keyword_set(probes) then probes = ['a','b','c','d','e']
if keyword_set(get_moments) then if not keyword_set(comps)  then comps = ['density','velocity','T3']
if not keyword_set(units) then units='eflux'

;-----------------------------------------------------------------------

for p = 0,n_elements(probes)-1 do begin
    probe= probes[p]
    thx = 'th'+probe
    for t=0,n_elements(types)-1 do begin
        type = types(t)
        format = thx+'_'+type
        times= thm_part_dist(format,/times)
        ns = n_elements(times) * keyword_set(times)
        dprint,format,ns,' elements'

        if ns gt 0  then begin

          dat = conv_units(thm_part_dist(format,index=0),units)
          energy = average(dat.energy,2)
          if keyword_set(comps) then moms = replicate( moments_3d(), ns )
          time = replicate(!values.d_nan,ns)
          spec = fltarr( ns, dat.nenergy )

          for i=1L,ns-1  do begin    ; Change to start at 0L after jim fixes his code
              dat = thm_part_dist(format,index=i)
              dat.sc_pot = 4.        ; needs to read EFI data to be correct.
              time[i] = dat.time
              spec[ i, *] = average(dat.data,2)
              if  keyword_set(comps) then moms[i] = moments_3d( dat )
              dprint,dwait=10.,format,i,'/',ns,'    ',time_string(dat.time)
          endfor

          if not keyword_set(no_tplot) then begin
              prefix = thx+'_'+type+'_'
              suffix = '_'+strlowcase(units)

              store_data,prefix+'en'+suffix, data= {x:time, y:spec ,v:energy },dlim={spec:1,zlog:1,ylog:1}
              for i = 0, n_elements(comps)-1 do begin

                  value = reform(transpose( struct_value(moms,comps[i]) ) )
;                  printdat,value,varname= comps[i]
                  store_data,prefix+comps[i],data= { x: moms.time,  y: value }
              endfor
          endif
        endif
    endfor
endfor


end


